@@ -1,8 +1,5 @@
 package Tkx::LabEntry;
 
-use strict;
-our $VERSION = '1.10_03';
-
 use base qw(Tkx::widget Tkx::MegaConfig);
 
 __PACKAGE__->_Mega("tkx_LabEntry");
